@@ -61,14 +61,13 @@ class ElasticsearchClient(Elasticsearch):
                 api_key=self.config.ELASTICSEARCH_API_KEY,
                 request_timeout=self.config.ELASTICSEARCH_REQUEST_TIMEOUT,
                 http_auth=self.config.http_auth,
-                use_ssl=self.config.use_ssl,
-                verify_certs=self.config.verify_certs,
-                connection_class=self.config.connection_class)
+                verify_certs=self.config.verify_certs
+            )
             self._log.info(f'Connected to elasticsearch: {client}')
             return client
 
         except Exception as e:
-            self._log.error(f'Cannot connect to elasticsearch: {self.config.ELASTICSEARCH_HOST}, {e}')
+            self._log.error(f'Cannot connect to elasticsearch: {self.config.ELASTICSEARCH_HOST}, {e}', enable_traceback=False)
 
         return False
 
