@@ -11,14 +11,15 @@ class InstagramConfig(object):
         self.login = login or environ('INSTAGRAM_LOGIN', '')
         self.password = password or environ('INSTAGRAM_PASSWORD', '')
 
-    def isConfigured(self):
+    @property
+    def is_configured(self):
         if self.login and self.password:
             log.info(f'config ready')
             return True
-        log.error(f'missing login and password', enable_traceback=False)
+        log.warn(f'missing login and password')
         return False
 
     def __repr__(self):
-        if self.isConfigured():
+        if self.is_configured:
             return f'ready'
         return f'not ready'
