@@ -9,13 +9,13 @@ c = MinioClient()
 class ClientTest(unittest.TestCase):
 
     def test_isConnected(self):
-        if c.isConnected():
-            self.assertTrue(c.isConnected())
+        if c.is_connected():
+            self.assertTrue(c.is_connected())
         else:
-            self.assertFalse(c.isConnected())
+            self.assertFalse(c.is_connected())
 
     def test_clear_bucket(self):
-        if c.isConnected():
+        if c.is_connected():
             bucket = c.make_bucket('AAAAAA')
             if c.list_objects(bucket):
                 self.assertTrue(c.remove_objects(bucket))
