@@ -25,7 +25,8 @@ class SplunkSoarConfig:
     def __repr__(self):
         return f'{self.__dict__}'
 
-    def isReady(self) -> bool:
+    @property
+    def is_ready(self) -> bool:
         if self.host:
             return True
         log.warn(f'bad config')
