@@ -6,7 +6,7 @@ c = SplunkSoarClient()
 
 
 class TestClient(unittest.TestCase):
-    if c.isConnected():
+    if c.is_connected():
         def test_list_app_run(self):
             self.assertTrue(c.list_app_run(page_size=1))
 
