@@ -6,7 +6,7 @@ c = SplunkSoarClient()
 
 
 class TestClient(unittest.TestCase):
-    if c.isConnected():
+    if c.is_connected():
         def test_list_app_run_generator(self):
             self.assertTrue([x for x in c.list_app_run_generator(page_size=1)])
 
